==> spirit_hub-0.0.1.11.tar.gz: spirit_hub-0.0.1.11/e2e/cypress/e2e/features/views/operations.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('There is on operation with all the column', () => {
  cy.appFactories([
    [
      'create',
      'operation',
      'with_tagset_root',
      { code: 'OPCODE', title: 'Operation 1', start_date: new Date(), end_date: new Date(), type: 'Vente', city: 'Paris', postal_code: '75000', agency: 'Agence Paris' },
    ],
  ]);
});

Then('I should see the right columns', () => {
  cy.get('#model_table td').eq(1).contains('OPCODE');
  cy.get('#model_table td').eq(2).contains('Operation 1');
  cy.get('#model_table td').eq(3).contains('Paris');
  cy.get('#model_table td').eq(4).contains('75000');
  cy.get('#model_table td').eq(5).contains('En cours');
  cy.get('#model_table td').eq(6).contains('Agence Paris');
  cy.get('#model_table td').eq(7).contains('Vente');
});

Given('There is some operations', () => {
  cy.appFactories([['create_list', 'operation', 5, 'with_tagset_root', { responsible: '1' }]]);
});

Then('I can sort operations', () => {
  cy.get('#model_table tbody').then($tbody => {
    const firstTitle = $tbody.find('tr:first td').eq(2).text();
    const lastTitle = $tbody.find('tr:last td').eq(2).text();

    cy.get('#model_table th').eq(2).find('a').click();

    cy.get('#model_table tbody tr:first td')
      .eq(2)
      .should($cell => {
        expect($cell.text()).to.equal(lastTitle);
      });

    cy.get('#model_table tbody tr:last td')
      .eq(2)
      .should($cell => {
        expect($cell.text()).to.equal(firstTitle);
      });

    cy.get('#model_table th').eq(2).find('a').click();

    cy.get('#model_table tbody tr:first td')
      .eq(2)
      .should($cell => {
        expect($cell.text()).to.equal(firstTitle);
      });

    cy.get('#model_table tbody tr:last td')
      .eq(2)
      .should($cell => {
        expect($cell.text()).to.equal(lastTitle);
      });
  });
});

Given('There is a lot of operations', () => {
  cy.appFactories([['create_list', 'operation', 20, 'with_tagset_root']]);
});

Then('I can paginate operations', () => {
  cy.get('select[name="per_page"]').select('5');
  cy.get('#model_table tbody tr').should('have.length', 5);
  cy.get('.pagination a').eq(0).should('have.class', 'cursor-not-allowed');
  cy.get('.pagination a.bg-primary').contains('1');
  cy.get('.pagination a').eq(4).contains('4');
  cy.get('.pagination a').contains('3').click();
  cy.get('#model_table tbody tr').should('have.length', 5);
  cy.get('.pagination a').eq(0).should('not.have.class', 'cursor-not-allowed');
  cy.get('.pagination a.bg-primary').contains('3');
  cy.get('.pagination a').eq(4).contains('4');
});

Then('I can go to operation root tagset', () => {
  cy.get('#model_table tbody tr:first td:last a:first').click();
  cy.url().should('include', '/directories');
});

Given('There is a valid classement plan', () => {
  cy.appFactories([['create', 'classement_plan', { title: 'Plan 1' }]]);
});

When('I click on the add operation button', () => {
  cy.get('form[action="/spirit_hub/operations/new"] button').click();
});

When('I fill the new operation form', () => {
  cy.get('input#operation_title').type('Operation 1');
  cy.get('input#operation_code').type('OPCODE');
  cy.get('input#operation_address').type('1 rue de Paris');
  cy.get('input#operation_postal_code').type('75000');
  cy.get('input#operation_city').type('Paris');
  cy.get('input#operation_agency').type('Agence Paris');
  cy.get('input#operation_type').type('Vente');
  cy.get('select#operation_classement_plan_id').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Plan 1').first().click();
  cy.get('input#operation_start_date').type('2024-01-01');
  cy.get('input#operation_end_date').type('2025-01-01');
  cy.get('select#operation_responsible').next('div').click();
  cy.get('.ss-search:visible input').first().type('admin');
  cy.contains('.ss-list:visible > .ss-option', 'admin').first().click();
  cy.get('select#operation_current_user_id').next('div').click();
  cy.get('.ss-search:visible input').first().type('admin');
  cy.contains('.ss-list:visible > .ss-option', 'admin').first().click();
});

When('I submit the operation form', () => {
  cy.get('form button[data-base-form-target="submitButton"]').click();
});

When('I click on the edit operation button', () => {
  cy.get('#model_table tbody tr:first td:last button[title="Modifier"]').click();
});

When('I change the operation title', () => {
  cy.get('input#operation_title').clear().type('Operation 2');
});

Then('I should see the operation title changed', () => {
  cy.get('#model_table tbody tr:first td').eq(2).contains('Operation 2');
});

Given('There is operations with code', () => {
  cy.appFactories([['create', 'operation', { code: 'OPCODE', title: 'Operation 1' }]]);
  cy.appFactories([['create', 'operation', { code: 'OPCODE2', title: 'Operation 2' }]]);
});

When('I fill the code with an existing code', () => {
  cy.get('input#operation_code').clear();
  cy.get('input#operation_code').type('OPCODE');
});

Then('I should see an code error message', () => {
  cy.get('#modal').contains('Code is already taken');
});

Given('There is one tagset todo with all columns', () => {
  cy.appFactories([['create', 'operation', { id: 'operation1', title: 'Operation 1' }]]);
  cy.appFactories([['create', 'tagset_doc', 'with_informed', 'with_file', { responsible: '1', parent_tagset_ids: ['a'], percent: 20, operation_id: 'operation1' }]]);
});

Given('There is some todos docs and some directories', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', parent_tagset_ids: ['a'], percent: 20 }]]);
  cy.appFactories([['create_list', 'tagset_directory', 10, { responsible: '1' }]]);
});

// Add doc
Then('I should not see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 5);
});

Then('I should see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 6);
});

When('I click on the last created doc', () => {
  cy.get('#model_table tbody tr:first td:last a:first').click();
});

Then('I should see the history journal entries', () => {
  cy.get('button#history-journal-entries').click();
});

Given('There is a doc to validate on my todos page', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_state', { state_key: 'to_validate', accounted: ['1'], percent: 20, responsible: '1', parent_tagset_ids: ['a'] }]]);
});

Then('I can download the operation tree file', () => {
  cy.get('a').contains('Télécharger').click();
  const downloadsFolder = Cypress.config('downloadsFolder');
  cy.readFile(`${downloadsFolder}/Plan 1.csv`).should('exist');
});

==> spirit_hub-0.1.1.6.tar.gz: spirit_hub-0.1.1.6/e2e/cypress/e2e/features/views/operations.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('There is on operation with all the column', () => {
  cy.appFactories([
    [
      'create',
      'operation',
      'with_tagset_root',
      { code: 'OPCODE', title: 'Operation 1', start_date: new Date(), end_date: new Date(), type: 'Vente', city: 'Paris', postal_code: '75000', agency: 'Agence Paris' },
    ],
  ]);
});

Then('I should see the right columns', () => {
  cy.get('#model_table td').eq(1).contains('OPCODE');
  cy.get('#model_table td').eq(2).contains('Operation 1');
  cy.get('#model_table td').eq(3).contains('Paris');
  cy.get('#model_table td').eq(4).contains('75000');
  cy.get('#model_table td').eq(5).contains('En cours');
  cy.get('#model_table td').eq(6).contains('Agence Paris');
  cy.get('#model_table td').eq(7).contains('Vente');
});

Given('There is some operations', () => {
  cy.appFactories([['create_list', 'operation', 5, 'with_tagset_root', { responsible: '1' }]]);
});

Then('I can sort operations', () => {
  cy.get('#model_table tbody').then($tbody => {
    const firstTitle = $tbody.find('tr:first td').eq(2).text();
    const lastTitle = $tbody.find('tr:last td').eq(2).text();

    cy.get('#model_table th').eq(2).find('button').click();

    cy.get('#model_table tbody tr:first td')
      .eq(2)
      .should($cell => {
        expect($cell.text()).to.equal(lastTitle);
      });

    cy.get('#model_table tbody tr:last td')
      .eq(2)
      .should($cell => {
        expect($cell.text()).to.equal(firstTitle);
      });

    cy.get('#model_table th').eq(2).find('button').click();

    cy.get('#model_table tbody tr:first td')
      .eq(2)
      .should($cell => {
        expect($cell.text()).to.equal(firstTitle);
      });

    cy.get('#model_table tbody tr:last td')
      .eq(2)
      .should($cell => {
        expect($cell.text()).to.equal(lastTitle);
      });
  });
});

Given('There is a lot of operations', () => {
  cy.appFactories([['create_list', 'operation', 20, 'with_tagset_root']]);
});

Then('I can paginate operations', () => {
  cy.get('select[name="per_page"]').select('5');
  cy.get('#model_table tbody tr').should('have.length', 5);
  cy.get('.pagination a').eq(0).should('have.class', 'cursor-not-allowed');
  cy.get('.pagination a.bg-primary').contains('1');
  cy.get('.pagination a').eq(4).contains('4');
  cy.get('.pagination a').contains('3').click();
  cy.get('#model_table tbody tr').should('have.length', 5);
  cy.get('.pagination a').eq(0).should('not.have.class', 'cursor-not-allowed');
  cy.get('.pagination a.bg-primary').contains('3');
  cy.get('.pagination a').eq(4).contains('4');
});

Then('I can go to operation root tagset', () => {
  cy.get('#model_table tbody tr:first td:last a:first').click();
  cy.url().should('include', '/directories');
});

Given('There is a valid classement plan', () => {
  cy.appFactories([['create', 'classement_plan', { title: 'Plan 1' }]]);
});

When('I click on the add operation button', () => {
  cy.get('form[action="/spirit_hub/operations/new"] button').click();
});

When('I fill the new operation form', () => {
  cy.get('input#operation_title').type('Operation 1');
  cy.get('input#operation_code').type('OPCODE');
  cy.get('input#operation_address').type('1 rue de Paris');
  cy.get('input#operation_postal_code').type('75000');
  cy.get('input#operation_city').type('Paris');
  cy.get('input#operation_agency').type('Agence Paris');
  cy.get('input#operation_type').type('Vente');
  cy.get('select#operation_classement_plan_id').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Plan 1').first().click();
  cy.get('input#operation_start_date').type('2024-01-01');
  cy.get('input#operation_end_date').type('2025-01-01');
  cy.get('select#operation_responsible').next('div').click();
  cy.get('.ss-search:visible input').first().type('admin');
  cy.contains('.ss-list:visible > .ss-option', 'admin').first().click();
  cy.get('select#operation_current_user_id').next('div').click();
  cy.get('.ss-search:visible input').first().type('admin');
  cy.contains('.ss-list:visible > .ss-option', 'admin').first().click();
});

When('I submit the operation form', () => {
  cy.get('form button[data-base-form-target="submitButton"]').click();
});

When('I click on the edit operation button', () => {
  cy.get('#model_table tbody tr:first td:last button[title="Modifier"]').click();
});

When('I change the operation title', () => {
  cy.get('input#operation_title').clear().type('Operation 2');
});

Then('I should see the operation title changed', () => {
  cy.get('#model_table tbody tr:first td').eq(2).contains('Operation 2');
});

Given('There is operations with code', () => {
  cy.appFactories([['create', 'operation', { code: 'OPCODE', title: 'Operation 1' }]]);
  cy.appFactories([['create', 'operation', { code: 'OPCODE2', title: 'Operation 2' }]]);
});

When('I fill the code with an existing code', () => {
  cy.get('input#operation_code').clear();
  cy.get('input#operation_code').type('OPCODE');
});

Then('I should see an code error message', () => {
  cy.get('#modal').contains('Le code est déjà pris');
});

Given('There is one tagset todo with all columns', () => {
  cy.appFactories([['create', 'operation', { id: 'operation1', title: 'Operation 1' }]]);
  cy.appFactories([['create', 'tagset_doc', 'with_informed', 'with_file', { responsible: '1', parent_tagset_ids: ['a'], percent: 20, operation_id: 'operation1' }]]);
});

Given('There is some todos docs and some directories', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', parent_tagset_ids: ['a'], percent: 20 }]]);
  cy.appFactories([['create_list', 'tagset_directory', 10, { responsible: '1' }]]);
});

// Add doc
Then('I should not see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 5);
});

Then('I should see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 6);
});

When('I click on the last created doc', () => {
  cy.get('#model_table tbody tr:first td:last a:first').click();
});

Then('I should see the history journal entries', () => {
  cy.get('button#history-journal-entries').click();
});

Given('There is a doc to validate on my todos page', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_state', { state_key: 'to_validate', accounted: ['1'], percent: 20, responsible: '1', parent_tagset_ids: ['a'] }]]);
});

Then('I can download the operation tree file', () => {
  cy.get('a').contains('Télécharger').click();
  const downloadsFolder = Cypress.config('downloadsFolder');
  cy.readFile(`${downloadsFolder}/Plan 1.csv`).should('exist');
});
